==> Spec-Recorder%20Ver.1.14.zip: Spec-Recorder Ver.1.14/cgi-bin/configmaker.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-
import ConfigParser

filesec = False
analyzesec = False

#conf = ConfigParser.SafeConfigParser()
#conf.read("./sr.conf")
#if conf.get("server", "server") == "on":
#	pass	

html = '''Content-Type: text/html; charset=UTF-8

<html>
<head>
  <title>SR HTTP Config maker</title>
</head>
<body>
<h1>SR HTTP Config maker</h1>
<p>ON・OFFを選択した項目のみ変更します。変更はすぐに反映されます。</p>
<form action="configmaker.py" method="post">
  <p>音声ファイルの自動消去</p>
  <select name="del_ogg">
	<option value="notsel">選択してください</option>
   <option value="off">off</option>
   <option value="on">on</option>
  </select><BR>
  <p>画像ファイルへのファイル名の書き込み</p>
  <select name="write_filename">
	<option value="notsel">選択してください</option>
   <option value="off">off</option>]
   <option value="on">on</option>
  </select><BR>
  <p>CSVファイルの書き出し</p>
  <select name="write_csv">
	<option value="notsel">選択してください</option>
    <option value="on">on</option>
    <option value="on">off</option>
  </select><BR>
  <p>自動エコーカウント</p>
  <select name="analyze">
	<option value="notsel">選択してください</option>
    <option value="on">on</option>
    <option value="off">off</option>
  </select><BR>
  <input type="submit" />
</form>
'''

f = open('./sr.conf', 'r')
print f.read

def brprint(string):#改行を付け加えて出力する。ただそれだけ
	print string + "<BR>"
	return
	
def writeconf(string):#sr.confに書き込む
	try:
		f = open('./sr.conf', 'a+')
		f.write(string + "\n")
	except IOError:
		print "書けなかった"
	finally:
		f.close()
	return

import cgi
f = cgi.FieldStorage()
print html# % f.getfirst('lang', '')
if f.getfirst('del_ogg', '') == "on":
	brprint("音声ファイルの自動削除を有効化")
	if filesec == False:
		writeconf("[file]")
		filesec = True
	writeconf("del_ogg = on")
elif f.getfirst('del_ogg', '') == "off":
	brprint("音声ファイルの自動削除を無効化")
	if filesec == False:
		writeconf("[file]")
		filesec = True
	writeconf("del_ogg = off")
#else
#	brprint("POST error!")	
if f.getfirst('write_filename', '') == "on":
	brprint("画像ファイルへのファイル名の書き込みを有効化")
	if filesec == False:
		writeconf("[file]")
		filesec = True
	writeconf("write_filename = on")
if f.getfirst('write_filename', '') == "off":
	brprint("画像ファイルへのファイル名の書き込みを無効化")
	if filesec == False:
		writeconf("[file]")
		filesec = True
	writeconf("write_filename = off")
if f.getfirst('write_csv', '') == "on":
	brprint("CSVファイルへの書き出しを有効化")
	if filesec == False:
		writeconf("[file]")
		filesec = True
	writeconf("write_csv = on")
if f.getfirst('write_csv', '') == "off":
	brprint("CSVファイルへの書き出しを無効化")
	if filesec == False:
		writeconf("[file]")
		filesec = True
	writeconf("write_csv = off")
if f.getfirst('analyze', '') == "on":
	brprint("自動エコーカウントを有効化")
	if analyzesec == False:
		writeconf("[analyze]")
		filesec = True
	writeconf("analyze = on")
if f.getfirst('analyze', '') == "off":
	brprint("自動エコーカウントを無効化")
	if analyzesec == False:
		writeconf("[analyze]")
		filesec = True
	writeconf("analyze = off")

==> Spec-Recorder%20Ver.1.31.zip: Spec-Recorder Ver.1.31/cgi-bin/configmaker.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-
import ConfigParser

filesec = False
analyzesec = False

#conf = ConfigParser.SafeConfigParser()
#conf.read("./sr.conf")
#if conf.get("server", "server") == "on":
#	pass	

html = '''Content-Type: text/html; charset=UTF-8

<html>
<head>
  <title>SR HTTP Config maker</title>
</head>
<body>
<h1>SR HTTP Config maker</h1>
<p>ON・OFFを選択した項目のみ変更します。変更はすぐに反映されます。</p>
<form action="configmaker.py" method="post">
  <p>音声ファイルの自動消去</p>
  <select name="del_ogg">
	<option value="notsel">選択してください</option>
   <option value="off">off</option>
   <option value="on">on</option>
  </select><BR>
  <p>画像ファイルへのファイル名の書き込み</p>
  <select name="write_filename">
	<option value="notsel">選択してください</option>
   <option value="off">off</option>]
   <option value="on">on</option>
  </select><BR>
  <p>CSVファイルの書き出し</p>
  <select name="write_csv">
	<option value="notsel">選択してください</option>
    <option value="on">on</option>
    <option value="on">off</option>
  </select><BR>
  <p>ZIP形式でデータをアーカイブ化</p>
  <select name="make_zip">
	<option value="notsel">選択してください</option>
    <option value="on">on</option>
    <option value="on">off</option>
  </select><BR>
  <p>自動エコーカウント</p>
  <select name="analyze">
	<option value="notsel">選択してください</option>
    <option value="on">on</option>
    <option value="off">off</option>
  </select><BR>
  <p>自動カウントのピクセルの比較対象</p>
  <select name="compared_with_pixels">
	<option value="notsel">選択してください</option>
    <option value="median">中央値</option>
    <option value="average">平均</option>
  </select><BR>
  <input type="submit" />
</form>
'''

f = open('./sr.conf', 'r')
print f.read

def brprint(string):#改行を付け加えて出力する。ただそれだけ
	print string + "<BR>"
	return
	
def writeconf(string):#sr.confに書き込む
	try:
		f = open('./sr.conf', 'a+')
		f.write(string + "\n")
	except IOError:
		print "書けなかった"
	finally:
		f.close()
	return

import cgi
f = cgi.FieldStorage()
print html# % f.getfirst('lang', '')
if f.getfirst('del_ogg', '') == "on":
	brprint("音声ファイルの自動削除を有効化")
	if filesec == False:
		writeconf("[file]")
		filesec = True
	writeconf("del_ogg = on")
elif f.getfirst('del_ogg', '') == "off":
	brprint("音声ファイルの自動削除を無効化")
	if filesec == False:
		writeconf("[file]")
		filesec = True
	writeconf("del_ogg = off")
#else
#	brprint("POST error!")	
if f.getfirst('write_filename', '') == "on":
	brprint("画像ファイルへのファイル名の書き込みを有効化")
	if filesec == False:
		writeconf("[file]")
		filesec = True
	writeconf("write_filename = on")
if f.getfirst('write_filename', '') == "off":
	brprint("画像ファイルへのファイル名の書き込みを無効化")
	if filesec == False:
		writeconf("[file]")
		filesec = True
	writeconf("write_filename = off")
if f.getfirst('write_csv', '') == "on":
	brprint("CSVファイルへの書き出しを有効化")
	if filesec == False:
		writeconf("[file]")
		filesec = True
	writeconf("write_csv = on")
if f.getfirst('write_csv', '') == "off":
	brprint("CSVファイルへの書き出しを無効化")
	if filesec == False:
		writeconf("[file]")
		filesec = True
	writeconf("write_csv = off")
if f.getfirst('make_zip', '') == "on":
	brprint("ZIP形式でのデータのアーカイブ化を有効化")
	if filesec == False:
		writeconf("[file]")
		filesec = True
	writeconf("make_zip = on")
if f.getfirst('make_zip', '') == "off":
	brprint("ZIP形式でのデータのアーカイブ化を無効化")
	if filesec == False:
		writeconf("[file]")
		filesec = True
	writeconf("make_zip = off")
if f.getfirst('analyze', '') == "on":
	brprint("自動エコーカウントを有効化")
	if analyzesec == False:
		writeconf("[analyze]")
		filesec = True
	writeconf("analyze = on")
if f.getfirst('analyze', '') == "off":
	brprint("自動エコーカウントを無効化")
	if analyzesec == False:
		writeconf("[analyze]")
		filesec = True
	writeconf("analyze = off")
	
if f.getfirst('compared_with_pixels', '') == "madian":
	brprint("自動エコーカウントのピクセルの比較対象を中央値と設定")
	if analyzesec == False:
		writeconf("[analyze]")
		filesec = True
	writeconf("analyze = median")
if f.getfirst('compared_with_pixels', '') == "average":
	brprint("自動エコーカウントのピクセルの比較対象を平均値と設定")
	if analyzesec == False:
		writeconf("[analyze]")
		filesec = True
	writeconf("analyze = average")
